@@ -29,8 +29,13 @@ class MyThread(Thread):
 def thread_run_cmd(cmd):
     t = MyThread(target=run_cmd, args=(cmd,), kwargs={})
     t.start()
-    t.join()
+    # t.join()
     
+def thread_run_deno_cmd(cmd):
+    t = MyThread(target=run_deno_cmd, args=(cmd,), kwargs={})
+    t.start()
+    # t.join()
+
 def get_page_content(url):
     # https://www.cnblogs.com/herbert/p/10789343.html
     # https://www.selenium.dev/documentation/webdriver/drivers/remote_webdriver/#tabs-1-1
